@@ -2,15 +2,16 @@
 import time
 
 from django.contrib.auth import authenticate
-from django.test import Client
 from django.http import Http404
+from django.test import Client
 from django.test import RequestFactory
 from django.test.utils import override_settings
 from django.utils import unittest
-from django_nopassword import views
 
-from django_nopassword.models import LoginCode
-from django_nopassword.utils import get_user_model
+from nopassword import views
+from nopassword.models import LoginCode
+from nopassword.utils import get_user_model
+from nopassword.backends import NoPasswordBackend
 
 from .models import NoUsernameUser
 
@@ -20,6 +21,10 @@ class TestLoginCodes(unittest.TestCase):
         self.user = get_user_model().objects.create(username='test_user')
         self.inactive_user = get_user_model().objects.create(username='inactive', is_active=False)
 
+    def tearDown(self):
+        self.user.delete()
+        self.inactive_user.delete()
+
     def test_login_backend(self):
         self.code = LoginCode.create_code_for_user(self.user)
         self.assertEqual(len(self.code.code), 20)
@@ -42,10 +47,6 @@ class TestLoginCodes(unittest.TestCase):
         time.sleep(3)
         self.assertIsNone(authenticate(username=self.user.username, code=self.timeout_code.code))
 
-    def tearDown(self):
-        self.user.delete()
-        self.inactive_user.delete()
-
 
 class AuthenticationBackendTests(unittest.TestCase):
 
@@ -65,6 +66,9 @@ class TestViews(unittest.TestCase):
         self.c = Client()
         self.user = get_user_model().objects.create(username='user')
 
+    def tearDown(self):
+        self.user.delete()
+
     def test_login(self):
         response = self.c.get('/accounts/login/')
         self.assertEqual(response.status_code, 200)
@@ -76,15 +80,31 @@ class TestViews(unittest.TestCase):
                                                                       'wrongcode'))
         self.assertEqual(login_with_code.status_code, 404)
 
-        login_with_code = self.c.get('/accounts/login-code/%s/%s/' % (
+        login_url = '/accounts/login-code/%s/%s/' % (
             self.user.username,
-            LoginCode.objects.all()[0].code)
+            LoginCode.objects.all()[0].code
         )
-        self.assertEqual(login_with_code.status_code, 302)
+        login_with_code = self.c.get(login_url)
+        self.assertEqual(login_with_code.status_code, 200)
+
+        login_post = self.c.post(login_url)
+        self.assertEqual(login_post.status_code, 302)
 
         logout = self.c.get('/accounts/logout/')
         self.assertEqual(logout.status_code, 302)
 
+    @override_settings(NOPASSWORD_POST_REDIRECT=False)
+    def test_login_with_get(self):
+        login = self.c.post('/accounts/login/?next=/secret/', {'username': self.user.username})
+        self.assertEqual(login.status_code, 200)
+
+        login_url = '/accounts/login-code/%s/%s/' % (
+            self.user.username,
+            LoginCode.objects.all()[0].code
+        )
+        login_with_code = self.c.get(login_url)
+        self.assertEqual(login_with_code.status_code, 302)
+
     @override_settings(NOPASSWORD_HIDE_USERNAME=True)
     def test_hide_username(self):
         response = self.c.get('/accounts/login/')
@@ -96,15 +116,16 @@ class TestViews(unittest.TestCase):
         login_with_code = self.c.get('/accounts/login-code/%s/' % 'wrongcode')
         self.assertEqual(login_with_code.status_code, 404)
 
-        login_with_code = self.c.get('/accounts/login-code/%s/' % LoginCode.objects.all()[0].code)
-        self.assertEqual(login_with_code.status_code, 302)
+        code_url = '/accounts/login-code/%s/' % LoginCode.objects.all()[0].code
+        login_with_code = self.c.get(code_url)
+        self.assertEqual(login_with_code.status_code, 200)
+
+        login_post = self.c.post(code_url)
+        self.assertEqual(login_post.status_code, 302)
 
         logout = self.c.get('/accounts/logout/')
         self.assertEqual(logout.status_code, 302)
 
-    def tearDown(self):
-        self.user.delete()
-
 
 class TestUsersJsonView(unittest.TestCase):
 
@@ -124,3 +145,21 @@ class TestUsersJsonView(unittest.TestCase):
         request = self.factory.get('/accounts/users.json')
         response = views.users_json(request)
         self.assertEqual(response.status_code, 200)
+
+
+class TestBackendUtils(unittest.TestCase):
+    def setUp(self):
+        self.user = get_user_model().objects.create(username='test_user')
+        self.inactive_user = get_user_model().objects.create(username='inactive', is_active=False)
+        self.backend = NoPasswordBackend()
+
+    def tearDown(self):
+        self.user.delete()
+        self.inactive_user.delete()
+
+    def test_verify_user(self):
+        self.assertTrue(self.backend.verify_user(self.user))
+        self.assertFalse(self.backend.verify_user(self.inactive_user))
+
+    def test_send_login_code(self):
+        self.assertRaises(NotImplementedError, self.backend.send_login_code)
